@@ -3,17 +3,17 @@
 //
 //  Copyright(C) 2001-2006 Taku Kudo <taku@chasen.org>
 //  Copyright(C) 2004-2006 Nippon Telegraph and Telephone Corporation
-#include <Rcpp.h>
+#include "feature_index.h"
 
 #include <algorithm>
 #include <cstring>
 #include <fstream>
 #include <string>
+
 #include "common.h"
-#include "feature_index.h"
-#include "param.h"
 #include "iconv_utils.h"
 #include "learner_node.h"
+#include "param.h"
 #include "scoped_ptr.h"
 #include "string_buffer.h"
 #include "utils.h"
@@ -21,18 +21,23 @@
 #define BUFSIZE (2048)
 #define POSSIZE (64)
 
-#define ADDB(b) do { const int id = this->id((b));  \
-    if (id != -1) feature_.push_back(id); } while (0)
+#define ADDB(b)                           \
+  do {                                    \
+    const int id = this->id((b));         \
+    if (id != -1) feature_.push_back(id); \
+  } while (0)
 
-#define COPY_FEATURE(ptr) do {                                          \
-    feature_.push_back(-1);                                             \
-    (ptr) = feature_freelist_.alloc(feature_.size());                   \
+#define COPY_FEATURE(ptr)                                                \
+  do {                                                                   \
+    feature_.push_back(-1);                                              \
+    (ptr) = feature_freelist_.alloc(feature_.size());                    \
     std::copy(feature_.begin(), feature_.end(), const_cast<int *>(ptr)); \
-    feature_.clear(); } while (0)
+    feature_.clear();                                                    \
+  } while (0)
 
 namespace MeCab {
 
-const char* FeatureIndex::getIndex(char **p, char **column, size_t max) {
+const char *FeatureIndex::getIndex(char **p, char **column, size_t max) {
   ++(*p);
 
   bool flg = false;
@@ -42,15 +47,23 @@ const char* FeatureIndex::getIndex(char **p, char **column, size_t max) {
     ++(*p);
   }  // undef flg
 
-  CHECK_DIE(**p =='[') << "getIndex(): unmatched '['";
+  CHECK_DIE(**p == '[') << "getIndex(): unmatched '['";
 
   size_t n = 0;
   ++(*p);
 
   for (;; ++(*p)) {
     switch (**p) {
-      case '0': case '1': case '2': case '3': case '4':
-      case '5': case '6': case '7': case '8': case '9':
+      case '0':
+      case '1':
+      case '2':
+      case '3':
+      case '4':
+      case '5':
+      case '6':
+      case '7':
+      case '8':
+      case '9':
         n = 10 * n + (**p - '0');
         break;
       case ']':
@@ -58,8 +71,8 @@ const char* FeatureIndex::getIndex(char **p, char **column, size_t max) {
           return 0;
         }
 
-        if (flg == true && ((std::strcmp("*", column[n]) == 0)
-                            || column[n][0] == '\0')) {
+        if (flg == true &&
+            ((std::strcmp("*", column[n]) == 0) || column[n][0] == '\0')) {
           return 0;
         }
         return column[n];  // return;
@@ -72,13 +85,11 @@ const char* FeatureIndex::getIndex(char **p, char **column, size_t max) {
   return 0;
 }
 
-void FeatureIndex::set_alpha(const double *alpha) {
-  alpha_ = alpha;
-}
+void FeatureIndex::set_alpha(const double *alpha) { alpha_ = alpha; }
 
 bool FeatureIndex::openTemplate(const Param &param) {
-  std::string filename = create_filename(param.get<std::string>("dicdir"),
-                                         FEATURE_FILE);
+  std::string filename =
+      create_filename(param.get<std::string>("dicdir"), FEATURE_FILE);
   std::ifstream ifs(WPATH(filename.c_str()));
   CHECK_DIE(ifs) << "no such file or directory: " << filename;
 
@@ -93,20 +104,19 @@ bool FeatureIndex::openTemplate(const Param &param) {
       continue;
     }
     CHECK_DIE(tokenize2(buf.get(), "\t ", column, 2) == 2)
-        << "format error: " <<filename;
+        << "format error: " << filename;
 
     if (std::strcmp(column[0], "UNIGRAM") == 0) {
       unigram_templs_.push_back(this->strdup(column[1]));
     } else if (std::strcmp(column[0], "BIGRAM") == 0) {
       bigram_templs_.push_back(this->strdup(column[1]));
     } else {
-      CHECK_DIE(false) << "format error: " <<  filename;
+      CHECK_DIE(false) << "format error: " << filename;
     }
   }
 
   // second, open rewrite rules
-  filename = create_filename(param.get<std::string>("dicdir"),
-                             REWRITE_FILE);
+  filename = create_filename(param.get<std::string>("dicdir"), REWRITE_FILE);
   rewrite_.open(filename.c_str());
 
   return true;
@@ -120,11 +130,11 @@ bool DecoderFeatureIndex::open(const Param &param) {
   const std::string modelfile = param.get<std::string>("model");
   // open the file as binary mode again and fallback to text file
   if (!openBinaryModel(param)) {
-    // std::cout << modelfile
-    //           << " is not a binary model. reopen it as text mode..."
-    //           << std::endl;
-    CHECK_DIE(openTextModel(param)) <<
-        "no such file or directory: " << modelfile;
+    Rcpp::Rcout << modelfile
+                << " is not a binary model. reopen it as text mode..."
+                << std::endl;
+    CHECK_DIE(openTextModel(param))
+        << "no such file or directory: " << modelfile;
   }
 
   if (!openTemplate(param)) {
@@ -135,7 +145,6 @@ bool DecoderFeatureIndex::open(const Param &param) {
   return true;
 }
 
-
 bool DecoderFeatureIndex::openFromArray(const char *begin, const char *end) {
   const char *ptr = begin;
   unsigned int maxid = 0;
@@ -163,11 +172,9 @@ bool DecoderFeatureIndex::openBinaryModel(const Param &param) {
     return false;
   }
   const std::string to = param.get<std::string>("charset");
-  CHECK_DIE(decode_charset(charset_) ==
-            decode_charset(to.c_str()))
+  CHECK_DIE(decode_charset(charset_) == decode_charset(to.c_str()))
       << "model charset and dictionary charset are different. "
-      << "model_charset=" << charset_
-      << " dictionary_charset=" << to;
+      << "model_charset=" << charset_ << " dictionary_charset=" << to;
 
   return true;
 }
@@ -179,9 +186,7 @@ bool DecoderFeatureIndex::openTextModel(const Param &param) {
                        model_buffer_.data() + model_buffer_.size());
 }
 
-void DecoderFeatureIndex::clear() {
-  feature_freelist_.free();
-}
+void DecoderFeatureIndex::clear() { feature_freelist_.free(); }
 
 void EncoderFeatureIndex::clear() {}
 
@@ -236,19 +241,13 @@ bool DecoderFeatureIndex::buildFeature(LearnerPath *path) {
   std::string lfeature2;
   std::string rfeature2;
 
-  CHECK_DIE(rewrite_.rewrite2(path->lnode->feature,
-                              &ufeature1,
-                              &lfeature1,
+  CHECK_DIE(rewrite_.rewrite2(path->lnode->feature, &ufeature1, &lfeature1,
                               &rfeature1))
-      << " cannot rewrite pattern: "
-      << path->lnode->feature;
+      << " cannot rewrite pattern: " << path->lnode->feature;
 
-  CHECK_DIE(rewrite_.rewrite2(path->rnode->feature,
-                              &ufeature2,
-                              &lfeature2,
+  CHECK_DIE(rewrite_.rewrite2(path->rnode->feature, &ufeature2, &lfeature2,
                               &rfeature2))
-      << " cannot rewrite pattern: "
-      << path->rnode->feature;
+      << " cannot rewrite pattern: " << path->rnode->feature;
 
   if (!buildUnigramFeature(path, ufeature2.c_str())) {
     return false;
@@ -271,26 +270,20 @@ bool EncoderFeatureIndex::buildFeature(LearnerPath *path) {
   std::string lfeature2;
   std::string rfeature2;
 
-  CHECK_DIE(rewrite_.rewrite2(path->lnode->feature,
-                              &ufeature1,
-                              &lfeature1,
+  CHECK_DIE(rewrite_.rewrite2(path->lnode->feature, &ufeature1, &lfeature1,
                               &rfeature1))
-      << " cannot rewrite pattern: "
-      << path->lnode->feature;
+      << " cannot rewrite pattern: " << path->lnode->feature;
 
-  CHECK_DIE(rewrite_.rewrite2(path->rnode->feature,
-                              &ufeature2,
-                              &lfeature2,
+  CHECK_DIE(rewrite_.rewrite2(path->rnode->feature, &ufeature2, &lfeature2,
                               &rfeature2))
-      << " cannot rewrite pattern: "
-      << path->rnode->feature;
+      << " cannot rewrite pattern: " << path->rnode->feature;
 
   {
     os_.clear();
     os_ << ufeature2 << ' ' << path->rnode->char_type << '\0';
     const std::string key(os_.str());
-    std::map<std::string, std::pair<const int *, size_t> >::iterator
-        it = feature_cache_.find(key);
+    std::map<std::string, std::pair<const int *, size_t> >::iterator it =
+        feature_cache_.find(key);
     if (it != feature_cache_.end()) {
       path->rnode->fvector = it->second.first;
       it->second.second++;
@@ -298,11 +291,9 @@ bool EncoderFeatureIndex::buildFeature(LearnerPath *path) {
       if (!buildUnigramFeature(path, ufeature2.c_str())) {
         return false;
       }
-      feature_cache_.insert(std::pair
-                            <std::string, std::pair<const int *, size_t> >
-                            (key,
-                             std::pair<const int *, size_t>
-                             (path->rnode->fvector, 1)));
+      feature_cache_.insert(
+          std::pair<std::string, std::pair<const int *, size_t> >(
+              key, std::pair<const int *, size_t>(path->rnode->fvector, 1)));
     }
   }
 
@@ -310,18 +301,17 @@ bool EncoderFeatureIndex::buildFeature(LearnerPath *path) {
     os_.clear();
     os_ << rfeature1 << ' ' << lfeature2 << '\0';
     std::string key(os_.str());
-    std::map<std::string, std::pair<const int *, size_t> >::iterator
-        it = feature_cache_.find(key);
+    std::map<std::string, std::pair<const int *, size_t> >::iterator it =
+        feature_cache_.find(key);
     if (it != feature_cache_.end()) {
       path->fvector = it->second.first;
       it->second.second++;
     } else {
       if (!buildBigramFeature(path, rfeature1.c_str(), lfeature2.c_str()))
         return false;
-      feature_cache_.insert(std::pair
-                            <std::string, std::pair<const int *, size_t> >
-                            (key, std::pair<const int *, size_t>
-                             (path->fvector, 1)));
+      feature_cache_.insert(
+          std::pair<std::string, std::pair<const int *, size_t> >(
+              key, std::pair<const int *, size_t>(path->fvector, 1)));
     }
   }
 
@@ -341,31 +331,39 @@ bool FeatureIndex::buildUnigramFeature(LearnerPath *path,
   ubuf[ubuf.size() - 1] = '\0';
   const size_t usize = tokenizeCSV(ubuf.get(), F.get(), F.size());
 
-  for (std::vector<const char*>::const_iterator it = unigram_templs_.begin();
+  for (std::vector<const char *>::const_iterator it = unigram_templs_.begin();
        it != unigram_templs_.end(); ++it) {
     const char *p = *it;
     os_.clear();
 
     for (; *p; p++) {
       switch (*p) {
-        default: os_ << *p; break;
-        case '\\': os_ << getEscapedChar(*++p); break;
+        default:
+          os_ << *p;
+          break;
+        case '\\':
+          os_ << getEscapedChar(*++p);
+          break;
         case '%': {
           switch (*++p) {
-            case 'F':  {
+            case 'F': {
               const char *r = getIndex(const_cast<char **>(&p), F.get(), usize);
               if (!r) goto NEXT;
               os_ << r;
             } break;
-            case 't':  os_ << (unsigned int)path->rnode->char_type;     break;
-            case 'u':  os_ << ufeature; break;
+            case 't':
+              os_ << (unsigned int)path->rnode->char_type;
+              break;
+            case 'u':
+              os_ << ufeature;
+              break;
             case 'w':
               if (path->rnode->stat == MECAB_NOR_NODE) {
                 os_.write(path->rnode->surface, path->rnode->length);
               }
               break;
             default:
-              CHECK_DIE(false) << "unknown meta char: " <<  *p;
+              CHECK_DIE(false) << "unknown meta char: " << *p;
           }
         }
       }
@@ -374,7 +372,8 @@ bool FeatureIndex::buildUnigramFeature(LearnerPath *path,
     os_ << '\0';
     ADDB(os_.str());
 
- NEXT: continue;
+  NEXT:
+    continue;
   }
 
   COPY_FEATURE(path->rnode->fvector);
@@ -382,8 +381,7 @@ bool FeatureIndex::buildUnigramFeature(LearnerPath *path,
   return true;
 }
 
-bool FeatureIndex::buildBigramFeature(LearnerPath *path,
-                                      const char *rfeature,
+bool FeatureIndex::buildBigramFeature(LearnerPath *path, const char *rfeature,
                                       const char *lfeature) {
   scoped_fixed_array<char, BUFSIZE> rbuf;
   scoped_fixed_array<char, BUFSIZE> lbuf;
@@ -391,23 +389,27 @@ bool FeatureIndex::buildBigramFeature(LearnerPath *path,
   scoped_fixed_array<char *, POSSIZE> L;
 
   feature_.clear();
-  std::strncpy(lbuf.get(),  rfeature, lbuf.size() - 1);
+  std::strncpy(lbuf.get(), rfeature, lbuf.size() - 1);
   lbuf[lbuf.size() - 1] = '\0';
-  std::strncpy(rbuf.get(),  lfeature, rbuf.size() - 1);
+  std::strncpy(rbuf.get(), lfeature, rbuf.size() - 1);
   rbuf[rbuf.size() - 1] = '\0';
 
   const size_t lsize = tokenizeCSV(lbuf.get(), L.get(), L.size());
   const size_t rsize = tokenizeCSV(rbuf.get(), R.get(), R.size());
 
-  for (std::vector<const char*>::const_iterator it = bigram_templs_.begin();
+  for (std::vector<const char *>::const_iterator it = bigram_templs_.begin();
        it != bigram_templs_.end(); ++it) {
     const char *p = *it;
     os_.clear();
 
     for (; *p; p++) {
       switch (*p) {
-        default: os_ << *p; break;
-        case '\\': os_ << getEscapedChar(*++p); break;
+        default:
+          os_ << *p;
+          break;
+        case '\\':
+          os_ << getEscapedChar(*++p);
+          break;
         case '%': {
           switch (*++p) {
             case 'L': {
@@ -420,10 +422,14 @@ bool FeatureIndex::buildBigramFeature(LearnerPath *path,
               if (!r) goto NEXT;
               os_ << r;
             } break;
-            case 'l':  os_ << lfeature; break;  // use lfeature as it is
-            case 'r':  os_ << rfeature; break;
+            case 'l':
+              os_ << lfeature;
+              break;  // use lfeature as it is
+            case 'r':
+              os_ << rfeature;
+              break;
             default:
-              CHECK_DIE(false) << "unknown meta char: " <<  *p;
+              CHECK_DIE(false) << "unknown meta char: " << *p;
           }
         }
       }
@@ -433,7 +439,8 @@ bool FeatureIndex::buildBigramFeature(LearnerPath *path,
 
     ADDB(os_.str());
 
- NEXT: continue;
+  NEXT:
+    continue;
   }
 
   COPY_FEATURE(path->fvector);
@@ -443,9 +450,7 @@ bool FeatureIndex::buildBigramFeature(LearnerPath *path,
 
 int DecoderFeatureIndex::id(const char *key) {
   const uint64_t fp = fingerprint(key, std::strlen(key));
-  const uint64_t *result = std::lower_bound(key_,
-                                            key_ + maxid_,
-                                            fp);
+  const uint64_t *result = std::lower_bound(key_, key_ + maxid_, fp);
   if (result == key_ + maxid_ || *result != fp) {
     return -1;
   }
@@ -467,12 +472,11 @@ int EncoderFeatureIndex::id(const char *key) {
   return -1;
 }
 
-void EncoderFeatureIndex::shrink(size_t freq,
-                                 std::vector<double> *observed) {
+void EncoderFeatureIndex::shrink(size_t freq, std::vector<double> *observed) {
   std::vector<size_t> freqv;
   // count fvector
   freqv.resize(maxid_);
-  for (std::map<std::string, std::pair<const int*, size_t> >::const_iterator
+  for (std::map<std::string, std::pair<const int *, size_t> >::const_iterator
            it = feature_cache_.begin();
        it != feature_cache_.end(); ++it) {
     for (const int *f = it->second.first; *f != -1; ++f) {
@@ -496,8 +500,8 @@ void EncoderFeatureIndex::shrink(size_t freq,
   }
 
   // update dic_
-  for (std::map<std::string, int>::iterator
-           it = dic_.begin(); it != dic_.end();) {
+  for (std::map<std::string, int>::iterator it = dic_.begin();
+       it != dic_.end();) {
     std::map<int, int>::const_iterator it2 = old2new.find(it->second);
     if (it2 != old2new.end()) {
       it->second = it2->second;
@@ -508,8 +512,9 @@ void EncoderFeatureIndex::shrink(size_t freq,
   }
 
   // update all fvector
-  for (std::map<std::string, std::pair<const int*, size_t> >::const_iterator
-           it = feature_cache_.begin(); it != feature_cache_.end(); ++it) {
+  for (std::map<std::string, std::pair<const int *, size_t> >::const_iterator
+           it = feature_cache_.begin();
+       it != feature_cache_.end(); ++it) {
     int *to = const_cast<int *>(it->second.first);
     for (const int *f = it->second.first; *f != -1; ++f) {
       std::map<int, int>::const_iterator it2 = old2new.find(*f);
@@ -536,18 +541,18 @@ void EncoderFeatureIndex::shrink(size_t freq,
   return;
 }
 
-bool FeatureIndex::compile(const Param &param,
-                           const char* txtfile, const char *binfile) {
+bool FeatureIndex::compile(const Param &param, const char *txtfile,
+                           const char *binfile) {
   std::string buf;
   FeatureIndex::convert(param, txtfile, &buf);
-  std::ofstream ofs(WPATH(binfile), std::ios::binary|std::ios::out);
+  std::ofstream ofs(WPATH(binfile), std::ios::binary | std::ios::out);
   CHECK_DIE(ofs) << "permission denied: " << binfile;
   ofs.write(buf.data(), buf.size());
   return true;
 }
 
-bool FeatureIndex::convert(const Param &param,
-                           const char* txtfile, std::string *output) {
+bool FeatureIndex::convert(const Param &param, const char *txtfile,
+                           std::string *output) {
   std::ifstream ifs(WPATH(txtfile));
   CHECK_DIE(ifs) << "no such file or directory: " << txtfile;
   scoped_fixed_array<char, BUF_SIZE> buf;
@@ -570,11 +575,10 @@ bool FeatureIndex::convert(const Param &param,
   std::string to = param.get<std::string>("charset");
 
   if (!from.empty()) {
-    CHECK_DIE(decode_charset(model_charset.c_str())
-              == decode_charset(from.c_str()))
+    CHECK_DIE(decode_charset(model_charset.c_str()) ==
+              decode_charset(from.c_str()))
         << "dictionary charset and model charset are different. "
-        << "dictionary_charset=" << from
-        << " model_charset=" << model_charset;
+        << "dictionary_charset=" << from << " model_charset=" << model_charset;
   } else {
     from = model_charset;
   }
@@ -585,8 +589,7 @@ bool FeatureIndex::convert(const Param &param,
 
   Iconv iconv;
   CHECK_DIE(iconv.open(from.c_str(), to.c_str()))
-            << "cannot create model from=" << from
-            << " to=" << to;
+      << "cannot create model from=" << from << " to=" << to;
 
   while (ifs.getline(buf.get(), buf.size())) {
     CHECK_DIE(tokenize2(buf.get(), "\t", column, 2) == 2)
@@ -600,7 +603,7 @@ bool FeatureIndex::convert(const Param &param,
 
   output->clear();
   unsigned int size = static_cast<unsigned int>(dic.size());
-  output->append(reinterpret_cast<const char*>(&size), sizeof(size));
+  output->append(reinterpret_cast<const char *>(&size), sizeof(size));
 
   char charset_buf[32];
   std::strncpy(charset_buf, to.c_str(), sizeof(charset_buf) - 1);
@@ -624,10 +627,8 @@ bool FeatureIndex::convert(const Param &param,
 }
 
 // TODO(taku): consider charset
-bool EncoderFeatureIndex::reopen(const char *filename,
-                                 const char *dic_charset,
-                                 std::vector<double> *alpha,
-                                 Param *param) {
+bool EncoderFeatureIndex::reopen(const char *filename, const char *dic_charset,
+                                 std::vector<double> *alpha, Param *param) {
   close();
   std::ifstream ifs(WPATH(filename));
   if (!ifs) {
@@ -657,8 +658,7 @@ bool EncoderFeatureIndex::reopen(const char *filename,
 
   Iconv iconv;
   CHECK_DIE(iconv.open(model_charset.c_str(), dic_charset))
-      << "cannot create model from=" << model_charset
-      << " to=" << dic_charset;
+      << "cannot create model from=" << model_charset << " to=" << dic_charset;
 
   alpha->clear();
   CHECK_DIE(maxid_ == 0);
@@ -700,4 +700,4 @@ bool EncoderFeatureIndex::save(const char *filename, const char *header) const {
 
   return true;
 }
-}
+}  // namespace MeCab
