@@ -1,6 +1,6 @@
 testdata <- readRDS(system.file("testdata/testdata.rda", package = "gibasa"))
 
-df <- testdata[[7]]
+df <- testdata[["raw_counts"]]
 
 ### tf*idf ----
 test_that("tf*idf works", {
@@ -18,7 +18,10 @@ test_that("tf2*idf works", {
     bind_tf_idf2(df, tf = "tf2", idf = "idf") |>
     dplyr::select(doc_id, token, tf_idf) |>
     dplyr::arrange(doc_id, token, tf_idf)
-  expect_equal(res, dplyr::arrange(testdata[["tf2*idf"]], doc_id, token, tf_idf))
+  expect_equal(
+    res,
+    dplyr::arrange(testdata[["tf2*idf"]], doc_id, token, tf_idf)
+  )
 })
 
 ### tf2*idf2 ----
@@ -27,7 +30,10 @@ test_that("tf2*idf2 works", {
     bind_tf_idf2(df, tf = "tf2", idf = "idf2") |>
     dplyr::select(doc_id, token, tf_idf) |>
     dplyr::arrange(doc_id, token, tf_idf)
-  expect_equal(res, dplyr::arrange(testdata[["tf2*idf2"]], doc_id, token, tf_idf))
+  expect_equal(
+    res,
+    dplyr::arrange(testdata[["tf2*idf2"]], doc_id, token, tf_idf)
+  )
 })
 
 ### tf3*idf ----
@@ -36,7 +42,10 @@ test_that("tf3*idf works", {
     bind_tf_idf2(df, tf = "tf3", idf = "idf") |>
     dplyr::select(doc_id, token, tf_idf) |>
     dplyr::arrange(doc_id, token, tf_idf)
-  expect_equal(res, dplyr::arrange(testdata[["tf3*idf"]], doc_id, token, tf_idf))
+  expect_equal(
+    res,
+    dplyr::arrange(testdata[["tf3*idf"]], doc_id, token, tf_idf)
+  )
 })
 
 ### tf2*idf3 ----
@@ -45,7 +54,10 @@ test_that("tf2*idf3 works", {
     bind_tf_idf2(df, tf = "tf2", idf = "idf3") |>
     dplyr::select(doc_id, token, tf_idf) |>
     dplyr::arrange(doc_id, token, tf_idf)
-  expect_equal(res, dplyr::arrange(testdata[["tf2*idf3"]], doc_id, token, tf_idf))
+  expect_equal(
+    res,
+    dplyr::arrange(testdata[["tf2*idf3"]], doc_id, token, tf_idf)
+  )
 })
 
 ### tf2*idf4 ----
@@ -54,5 +66,30 @@ test_that("tf2*idf4 works", {
     bind_tf_idf2(df, tf = "tf2", idf = "idf4") |>
     dplyr::select(doc_id, token, tf_idf) |>
     dplyr::arrange(doc_id, token, tf_idf)
-  expect_equal(res, dplyr::arrange(testdata[["tf2*idf4"]], doc_id, token, tf_idf))
+  expect_equal(
+    res,
+    dplyr::arrange(testdata[["tf2*idf4"]], doc_id, token, tf_idf)
+  )
+})
+
+### tf*idf*norm ----
+test_that("tf*idf*norm works", {
+  res <-
+    bind_tf_idf2(df, tf = "tf", idf = "idf", norm = TRUE) |>
+    dplyr::select(doc_id, token, tf_idf) |>
+    dplyr::arrange(doc_id, token, tf_idf)
+  expect_equal(
+    res,
+    dplyr::arrange(testdata[["tf*idf*norm"]], doc_id, token, tf_idf)
+  )
+})
+
+### itf*df ----
+test_that("itf*df works", {
+  res <-
+    bind_tf_idf2(df, tf = "itf", idf = "df") |>
+    dplyr::select(doc_id, tf_idf) |>
+    dplyr::arrange(doc_id, tf_idf) |>
+    dplyr::filter(as.integer(doc_id) < 5)
+  expect_snapshot_value(res, style = "json2", cran = FALSE)
 })
